==> apache-shardingsphere-5.5.1-src.zip: apache-shardingsphere-5.5.1-src-release/mode/core/src/test/java/org/apache/shardingsphere/mode/state/StateContextTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.mode.state;

import org.apache.shardingsphere.infra.state.cluster.ClusterState;
import org.junit.jupiter.api.Test;

import static org.hamcrest.CoreMatchers.is;
import static org.hamcrest.MatcherAssert.assertThat;

class StateContextTest {
    
    private final StateContext stateContext = new StateContext(ClusterState.OK);
    
    @Test
    void assertGetClusterState() {
        assertThat(stateContext.getClusterState(), is(ClusterState.OK));
    }
    
    @Test
    void assertSwitchClusterState() {
        assertThat(stateContext.getClusterState(), is(ClusterState.OK));
        stateContext.switchClusterState(ClusterState.UNAVAILABLE);
        assertThat(stateContext.getClusterState(), is(ClusterState.UNAVAILABLE));
    }
}

==> apache-shardingsphere-5.5.3-src.zip: apache-shardingsphere-5.5.3-src-release/mode/core/src/test/java/org/apache/shardingsphere/mode/state/StateContextTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.mode.state;

import org.junit.jupiter.api.Test;

import static org.hamcrest.Matchers.is;
import static org.hamcrest.MatcherAssert.assertThat;

class StateContextTest {
    
    private final StateContext stateContext = new StateContext(ShardingSphereState.OK);
    
    @Test
    void assertGetClusterState() {
        assertThat(stateContext.getState(), is(ShardingSphereState.OK));
    }
    
    @Test
    void assertSwitchClusterState() {
        assertThat(stateContext.getState(), is(ShardingSphereState.OK));
        stateContext.switchState(ShardingSphereState.UNAVAILABLE);
        assertThat(stateContext.getState(), is(ShardingSphereState.UNAVAILABLE));
    }
}
